from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSPDatabaseMessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSPDatabaseMessages.proto',
  package='TSP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x19TSPDatabaseMessages.proto\x12\x03TSP\x1a\x11TSPMessages.proto\"0\n\x0c\x44\x61tabaseData\x12 \n\x04\x64\x61ta\x18\x01 \x02(\x0b\x32\x12.TSP.DataReference\"\x9a\x01\n\x13\x44\x61tabaseDataArchive\x12\x1c\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x11\x61pp_relative_path\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x02(\t\x12\x0e\n\x06length\x18\x04 \x01(\x04\x12\x0c\n\x04hash\x18\x05 \x01(\r\x12\x16\n\x08sharable\x18\x06 \x02(\x08:\x04true\"\xa9\x01\n\x18\x44\x61tabaseImageDataArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TSP.DatabaseDataArchive\x12\x35\n\x04type\x18\x02 \x02(\x0e\x32\'.TSP.DatabaseImageDataArchive.ImageType\"-\n\tImageType\x12\x0b\n\x07unknown\x10\x00\x12\n\n\x06\x62itmap\x10\x01\x12\x07\n\x03pdf\x10\x02')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,])



_DATABASEIMAGEDATAARCHIVE_IMAGETYPE = _descriptor.EnumDescriptor(
  name='ImageType',
  full_name='TSP.DatabaseImageDataArchive.ImageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='bitmap', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='pdf', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=385,
  serialized_end=430,
)
_sym_db.RegisterEnumDescriptor(_DATABASEIMAGEDATAARCHIVE_IMAGETYPE)


_DATABASEDATA = _descriptor.Descriptor(
  name='DatabaseData',
  full_name='TSP.DatabaseData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='TSP.DatabaseData.data', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=101,
)


_DATABASEDATAARCHIVE = _descriptor.Descriptor(
  name='DatabaseDataArchive',
  full_name='TSP.DatabaseDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='TSP.DatabaseDataArchive.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_relative_path', full_name='TSP.DatabaseDataArchive.app_relative_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='TSP.DatabaseDataArchive.display_name', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='TSP.DatabaseDataArchive.length', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='TSP.DatabaseDataArchive.hash', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharable', full_name='TSP.DatabaseDataArchive.sharable', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=258,
)


_DATABASEIMAGEDATAARCHIVE = _descriptor.Descriptor(
  name='DatabaseImageDataArchive',
  full_name='TSP.DatabaseImageDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSP.DatabaseImageDataArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSP.DatabaseImageDataArchive.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATABASEIMAGEDATAARCHIVE_IMAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=430,
)

_DATABASEDATA.fields_by_name['data'].message_type = TSPMessages__pb2._DATAREFERENCE
_DATABASEDATAARCHIVE.fields_by_name['data'].message_type = TSPMessages__pb2._REFERENCE
_DATABASEIMAGEDATAARCHIVE.fields_by_name['super'].message_type = _DATABASEDATAARCHIVE
_DATABASEIMAGEDATAARCHIVE.fields_by_name['type'].enum_type = _DATABASEIMAGEDATAARCHIVE_IMAGETYPE
_DATABASEIMAGEDATAARCHIVE_IMAGETYPE.containing_type = _DATABASEIMAGEDATAARCHIVE
DESCRIPTOR.message_types_by_name['DatabaseData'] = _DATABASEDATA
DESCRIPTOR.message_types_by_name['DatabaseDataArchive'] = _DATABASEDATAARCHIVE
DESCRIPTOR.message_types_by_name['DatabaseImageDataArchive'] = _DATABASEIMAGEDATAARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatabaseData = _reflection.GeneratedProtocolMessageType('DatabaseData', (_message.Message,), dict(
  DESCRIPTOR = _DATABASEDATA,
  __module__ = 'TSPDatabaseMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DatabaseData)
  ))
_sym_db.RegisterMessage(DatabaseData)

DatabaseDataArchive = _reflection.GeneratedProtocolMessageType('DatabaseDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _DATABASEDATAARCHIVE,
  __module__ = 'TSPDatabaseMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DatabaseDataArchive)
  ))
_sym_db.RegisterMessage(DatabaseDataArchive)

DatabaseImageDataArchive = _reflection.GeneratedProtocolMessageType('DatabaseImageDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _DATABASEIMAGEDATAARCHIVE,
  __module__ = 'TSPDatabaseMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DatabaseImageDataArchive)
  ))
_sym_db.RegisterMessage(DatabaseImageDataArchive)


# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KNCommandArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSACommandArchives_sos_pb2 as TSACommandArchives__sos__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='KNCommandArchives_sos.proto',
  package='KN',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1bKNCommandArchives_sos.proto\x12\x02KN\x1a\x1cTSACommandArchives_sos.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\"\xfb\x01\n-InducedVerifyDocumentWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12%\n\x12slide_node_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12$\n\x1cslide_node_id_list_undefined\x18\x03 \x01(\x08\x12,\n\x19master_slide_node_id_list\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12+\n#master_slide_node_id_list_undefined\x18\x05 \x01(\x08\"\x80\x01\n4InducedVerifyDrawableZOrdersWithServerCommandArchive\x12H\n\x05super\x18\x01 \x02(\x0b\x32\x39.TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive\"S\n CommandSlideReapplyMasterArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSA.CommandReapplyMasterArchive')
  ,
  dependencies=[TSACommandArchives__sos__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,])




_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDocumentWithServerCommandArchive',
  full_name='KN.InducedVerifyDocumentWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_list', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.slide_node_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_list_undefined', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.slide_node_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_slide_node_id_list', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.master_slide_node_id_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_slide_node_id_list_undefined', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.master_slide_node_id_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=355,
)


_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDrawableZOrdersWithServerCommandArchive',
  full_name='KN.InducedVerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.InducedVerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=486,
)


_COMMANDSLIDEREAPPLYMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandSlideReapplyMasterArchive',
  full_name='KN.CommandSlideReapplyMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideReapplyMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=571,
)

_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['slide_node_id_list'].message_type = TSPMessages__pb2._UUID
_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['master_slide_node_id_list'].message_type = TSPMessages__pb2._UUID
_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSACommandArchives__sos__pb2._INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
_COMMANDSLIDEREAPPLYMASTERARCHIVE.fields_by_name['super'].message_type = TSACommandArchives__sos__pb2._COMMANDREAPPLYMASTERARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDocumentWithServerCommandArchive'] = _INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDrawableZOrdersWithServerCommandArchive'] = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideReapplyMasterArchive'] = _COMMANDSLIDEREAPPLYMASTERARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InducedVerifyDocumentWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDocumentWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE,
  __module__ = 'KNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.InducedVerifyDocumentWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyDocumentWithServerCommandArchive)

InducedVerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'KNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.InducedVerifyDrawableZOrdersWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyDrawableZOrdersWithServerCommandArchive)

CommandSlideReapplyMasterArchive = _reflection.GeneratedProtocolMessageType('CommandSlideReapplyMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEREAPPLYMASTERARCHIVE,
  __module__ = 'KNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideReapplyMasterArchive)
  ))
_sym_db.RegisterMessage(CommandSlideReapplyMasterArchive)


# @@protoc_insertion_point(module_scope)



import os
import warnings
import plistlib
import urllib
from colorama import init as colorama_init
from colorama import Fore
from keynote_parser import (
    __version__,
    __supported_keynote_version__,
    __new_issue_url__,
    __command_line_invocation__,
)
from keynote_parser.macos_app_version import MacOSAppVersion

DEFAULT_KEYNOTE_INSTALL_PATH = '/Applications/Keynote.app'
VERSION_PLIST_PATH = 'Contents/version.plist'


colorama_init()


def get_installed_keynote_version():
    try:
        fp = open(os.path.join(DEFAULT_KEYNOTE_INSTALL_PATH, VERSION_PLIST_PATH), 'rb')
    except IOError:
        return None
    version_dict = plistlib.load(fp)
    return MacOSAppVersion(
        version_dict['CFBundleShortVersionString'],
        int(version_dict['CFBundleVersion']),
        version_dict['ProductBuildVersion'],
    )


class KeynoteVersionWarning(UserWarning):
    def __init__(self, installed_keynote_version):
        issue_title = "Please add support for Keynote %s" % installed_keynote_version
        new_issue_url = __new_issue_url__ + "?" + urllib.parse.urlencode({"title": issue_title})
        super(UserWarning, self).__init__(
            (
                "KeynoteVersionWarning: " + Fore.RESET
                + "This version of keynote_parser (%s) was not built with support "
                "for\nthe currently installed version of Keynote.\n"
                "\tkeynote_parser version:    %s\n"
                "\tsupported Keynote version: %s\n"
                "\tinstalled Keynote version: %s\n"
                "\n"
                "Some presentation files may not be editable, or data corruption may occur.\n"
                "To get rid of this warning:\n"
                "\t- try %supgrading %skeynote-parser%s (pip install --upgrade keynote-parser)\n"
                "\t- %ssubmit an issue%s if no new version is available:\n"
                "\t\t%s\n"
                "\t- use the %swarnings%s module to suppress %sKeynoteVersionWarning%s:\n"
                "\t\tPYTHONWARNINGS=ignore:KeynoteVersionWarning ...\n"
            )
            % (
                __version__,
                __version__,
                __supported_keynote_version__,
                installed_keynote_version,
                Fore.CYAN,
                Fore.YELLOW,
                Fore.RESET,
                Fore.YELLOW,
                Fore.RESET,
                new_issue_url,
                Fore.CYAN,
                Fore.RESET,
                Fore.CYAN,
                Fore.RESET,
            )
        )


class CleanWarning(object):
    def custom_format_warning(self, message, *args):
        # Nasty hack - by putting the initial colour in the formatter,
        # the Warnings filter still lets users ignore this warning as
        # the message itself doesn't start with an ANSI escape sequence.
        return Fore.YELLOW + str(message) + "\n"

    def __enter__(self):
        self.old_formatwarning = warnings.formatwarning
        warnings.formatwarning = self.custom_format_warning

    def __exit__(self, *args, **kwargs):
        warnings.formatwarning = self.old_formatwarning


DID_WARN = False


def warn_once_on_newer_keynote():
    global DID_WARN
    if DID_WARN:
        return False

    installed_keynote_version = get_installed_keynote_version()
    if not installed_keynote_version:
        return False

    if __supported_keynote_version__ < installed_keynote_version:
        with CleanWarning():
            warnings.warn(KeynoteVersionWarning(installed_keynote_version))
        DID_WARN = True

    return DID_WARN


if not __command_line_invocation__:
    warn_once_on_newer_keynote()



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHArchives_Common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHArchives_Common.proto',
  package='TSCH',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x19TSCHArchives_Common.proto\x12\x04TSCH\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSDArchives.proto\x1a\x11TSSArchives.proto\x1a\x14TSCH3DArchives.proto\"B\n\x0bRectArchive\x12\x1a\n\x06origin\x18\x01 \x02(\x0b\x32\n.TSP.Point\x12\x17\n\x04size\x18\x02 \x02(\x0b\x32\t.TSP.Size\"5\n\x1b\x43hartsNSNumberDoubleArchive\x12\x16\n\x0enumber_archive\x18\x01 \x01(\x01\"7\n$ChartsNSArrayOfNSNumberDoubleArchive\x12\x0f\n\x07numbers\x18\x01 \x03(\x01\"\xd0\x01\n\x1c\x44\x45PRECATEDChart3DFillArchive\x12\x1e\n\x04\x66ill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x38\n\rlightingmodel\x18\x02 \x01(\x0b\x32!.TSCH.Chart3DLightingModelArchive\x12\x15\n\rtextureset_id\x18\x03 \x01(\t\x12)\n\tfill_type\x18\x04 \x01(\x0e\x32\x16.TSCH.FillPropertyType\x12\x14\n\x0cseries_index\x18\x05 \x01(\r\"@\n\x11\x43hartStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"C\n\x14\x43hartNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"A\n\x12LegendStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"D\n\x15LegendNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"D\n\x15\x43hartAxisStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"G\n\x18\x43hartAxisNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"F\n\x17\x43hartSeriesStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"I\n\x1a\x43hartSeriesNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"f\n\tGridValue\x12\x15\n\rnumeric_value\x18\x01 \x01(\x01\x12\x16\n\x0e\x64\x61te_value_1_0\x18\x02 \x01(\x01\x12\x16\n\x0e\x64uration_value\x18\x03 \x01(\x01\x12\x12\n\ndate_value\x18\x04 \x01(\x01\")\n\x07GridRow\x12\x1e\n\x05value\x18\x01 \x03(\x0b\x32\x0f.TSCH.GridValue\"H\n\x19ReferenceLineStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"K\n\x1cReferenceLineNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02*\xa6\x05\n\tChartType\x12\x16\n\x12undefinedChartType\x10\x00\x12\x15\n\x11\x63olumnChartType2D\x10\x01\x12\x12\n\x0e\x62\x61rChartType2D\x10\x02\x12\x13\n\x0flineChartType2D\x10\x03\x12\x13\n\x0f\x61reaChartType2D\x10\x04\x12\x12\n\x0epieChartType2D\x10\x05\x12\x1c\n\x18stackedColumnChartType2D\x10\x06\x12\x19\n\x15stackedBarChartType2D\x10\x07\x12\x1a\n\x16stackedAreaChartType2D\x10\x08\x12\x16\n\x12scatterChartType2D\x10\t\x12\x14\n\x10mixedChartType2D\x10\n\x12\x16\n\x12twoAxisChartType2D\x10\x0b\x12\x15\n\x11\x63olumnChartType3D\x10\x0c\x12\x12\n\x0e\x62\x61rChartType3D\x10\r\x12\x13\n\x0flineChartType3D\x10\x0e\x12\x13\n\x0f\x61reaChartType3D\x10\x0f\x12\x12\n\x0epieChartType3D\x10\x10\x12\x1c\n\x18stackedColumnChartType3D\x10\x11\x12\x19\n\x15stackedBarChartType3D\x10\x12\x12\x1a\n\x16stackedAreaChartType3D\x10\x13\x12\x1e\n\x1amultiDataColumnChartType2D\x10\x14\x12\x1b\n\x17multiDataBarChartType2D\x10\x15\x12\x15\n\x11\x62ubbleChartType2D\x10\x16\x12\x1f\n\x1bmultiDataScatterChartType2D\x10\x17\x12\x1e\n\x1amultiDataBubbleChartType2D\x10\x18\x12\x14\n\x10\x64onutChartType2D\x10\x19\x12\x14\n\x10\x64onutChartType3D\x10\x1a*j\n\x08\x41xisType\x12\x15\n\x11\x61xis_type_unknown\x10\x00\x12\x0f\n\x0b\x61xis_type_x\x10\x01\x12\x0f\n\x0b\x61xis_type_y\x10\x02\x12\x11\n\raxis_type_pie\x10\x03\x12\x12\n\x0e\x61xis_type_size\x10\x04*g\n\rScatterFormat\x12\x1a\n\x16scatter_format_unknown\x10\x00\x12\x1d\n\x19scatter_format_separate_x\x10\x01\x12\x1b\n\x17scatter_format_shared_x\x10\x02*l\n\x0fSeriesDirection\x12\x1c\n\x18series_direction_unknown\x10\x00\x12\x1b\n\x17series_direction_by_row\x10\x01\x12\x1e\n\x1aseries_direction_by_column\x10\x02*\xe3\x01\n\x0fNumberValueType\x12\x1a\n\x16numberValueTypeDecimal\x10\x00\x12\x1b\n\x17numberValueTypeCurrency\x10\x01\x12\x1d\n\x19numberValueTypePercentage\x10\x02\x12\x1d\n\x19numberValueTypeScientific\x10\x03\x12\x1b\n\x17numberValueTypeFraction\x10\x04\x12\x17\n\x13numberValueTypeBase\x10\x05\x12#\n\x16numberValueTypeUnknown\x10\x99\xf8\xff\xff\xff\xff\xff\xff\xff\x01*\xba\x01\n\x13NegativeNumberStyle\x12\x1c\n\x18negativeNumberStyleMinus\x10\x00\x12\x1a\n\x16negativeNumberStyleRed\x10\x01\x12\"\n\x1enegativeNumberStyleParentheses\x10\x02\x12(\n$negativeNumberStyleRedAndParentheses\x10\x03\x12\x1b\n\x17negativeNumberStyleNone\x10\x04*\xeb\x02\n\x10\x46ractionAccuracy\x12\x1f\n\x1b\x66ractionAccuracyConflicting\x10\x00\x12)\n\x1c\x66ractionAccuracyUpToOneDigit\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1d\x66ractionAccuracyUpToTwoDigits\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1f\x66ractionAccuracyUpToThreeDigits\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x16\x66ractionAccuracyHalves\x10\x02\x12\x1c\n\x18\x66ractionAccuracyQuarters\x10\x04\x12\x1b\n\x17\x66ractionAccuracyEighths\x10\x08\x12\x1e\n\x1a\x66ractionAccuracySixteenths\x10\x10\x12\x1a\n\x16\x66ractionAccuracyTenths\x10\n\x12\x1e\n\x1a\x66ractionAccuracyHundredths\x10\x64')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCH3DArchives__pb2.DESCRIPTOR,])

_CHARTTYPE = _descriptor.EnumDescriptor(
  name='ChartType',
  full_name='TSCH.ChartType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='undefinedChartType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='columnChartType2D', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='barChartType2D', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='lineChartType2D', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='areaChartType2D', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='pieChartType2D', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedColumnChartType2D', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedBarChartType2D', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedAreaChartType2D', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='scatterChartType2D', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='mixedChartType2D', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='twoAxisChartType2D', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='columnChartType3D', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='barChartType3D', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='lineChartType3D', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='areaChartType3D', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='pieChartType3D', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedColumnChartType3D', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedBarChartType3D', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedAreaChartType3D', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataColumnChartType2D', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataBarChartType2D', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='bubbleChartType2D', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataScatterChartType2D', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataBubbleChartType2D', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='donutChartType2D', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='donutChartType3D', index=26, number=26,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1385,
  serialized_end=2063,
)
_sym_db.RegisterEnumDescriptor(_CHARTTYPE)

ChartType = enum_type_wrapper.EnumTypeWrapper(_CHARTTYPE)
_AXISTYPE = _descriptor.EnumDescriptor(
  name='AxisType',
  full_name='TSCH.AxisType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='axis_type_unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_x', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_y', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_pie', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_size', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2065,
  serialized_end=2171,
)
_sym_db.RegisterEnumDescriptor(_AXISTYPE)

AxisType = enum_type_wrapper.EnumTypeWrapper(_AXISTYPE)
_SCATTERFORMAT = _descriptor.EnumDescriptor(
  name='ScatterFormat',
  full_name='TSCH.ScatterFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='scatter_format_unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='scatter_format_separate_x', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='scatter_format_shared_x', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2173,
  serialized_end=2276,
)
_sym_db.RegisterEnumDescriptor(_SCATTERFORMAT)

ScatterFormat = enum_type_wrapper.EnumTypeWrapper(_SCATTERFORMAT)
_SERIESDIRECTION = _descriptor.EnumDescriptor(
  name='SeriesDirection',
  full_name='TSCH.SeriesDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='series_direction_unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_direction_by_row', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_direction_by_column', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2278,
  serialized_end=2386,
)
_sym_db.RegisterEnumDescriptor(_SERIESDIRECTION)

SeriesDirection = enum_type_wrapper.EnumTypeWrapper(_SERIESDIRECTION)
_NUMBERVALUETYPE = _descriptor.EnumDescriptor(
  name='NumberValueType',
  full_name='TSCH.NumberValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeDecimal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeCurrency', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypePercentage', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeScientific', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeFraction', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeBase', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeUnknown', index=6, number=-999,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2389,
  serialized_end=2616,
)
_sym_db.RegisterEnumDescriptor(_NUMBERVALUETYPE)

NumberValueType = enum_type_wrapper.EnumTypeWrapper(_NUMBERVALUETYPE)
_NEGATIVENUMBERSTYLE = _descriptor.EnumDescriptor(
  name='NegativeNumberStyle',
  full_name='TSCH.NegativeNumberStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleMinus', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleRed', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleParentheses', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleRedAndParentheses', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleNone', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2619,
  serialized_end=2805,
)
_sym_db.RegisterEnumDescriptor(_NEGATIVENUMBERSTYLE)

NegativeNumberStyle = enum_type_wrapper.EnumTypeWrapper(_NEGATIVENUMBERSTYLE)
_FRACTIONACCURACY = _descriptor.EnumDescriptor(
  name='FractionAccuracy',
  full_name='TSCH.FractionAccuracy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyConflicting', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyUpToOneDigit', index=1, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyUpToTwoDigits', index=2, number=-2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyUpToThreeDigits', index=3, number=-3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyHalves', index=4, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyQuarters', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyEighths', index=6, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracySixteenths', index=7, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyTenths', index=8, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyHundredths', index=9, number=100,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2808,
  serialized_end=3171,
)
_sym_db.RegisterEnumDescriptor(_FRACTIONACCURACY)

FractionAccuracy = enum_type_wrapper.EnumTypeWrapper(_FRACTIONACCURACY)
undefinedChartType = 0
columnChartType2D = 1
barChartType2D = 2
lineChartType2D = 3
areaChartType2D = 4
pieChartType2D = 5
stackedColumnChartType2D = 6
stackedBarChartType2D = 7
stackedAreaChartType2D = 8
scatterChartType2D = 9
mixedChartType2D = 10
twoAxisChartType2D = 11
columnChartType3D = 12
barChartType3D = 13
lineChartType3D = 14
areaChartType3D = 15
pieChartType3D = 16
stackedColumnChartType3D = 17
stackedBarChartType3D = 18
stackedAreaChartType3D = 19
multiDataColumnChartType2D = 20
multiDataBarChartType2D = 21
bubbleChartType2D = 22
multiDataScatterChartType2D = 23
multiDataBubbleChartType2D = 24
donutChartType2D = 25
donutChartType3D = 26
axis_type_unknown = 0
axis_type_x = 1
axis_type_y = 2
axis_type_pie = 3
axis_type_size = 4
scatter_format_unknown = 0
scatter_format_separate_x = 1
scatter_format_shared_x = 2
series_direction_unknown = 0
series_direction_by_row = 1
series_direction_by_column = 2
numberValueTypeDecimal = 0
numberValueTypeCurrency = 1
numberValueTypePercentage = 2
numberValueTypeScientific = 3
numberValueTypeFraction = 4
numberValueTypeBase = 5
numberValueTypeUnknown = -999
negativeNumberStyleMinus = 0
negativeNumberStyleRed = 1
negativeNumberStyleParentheses = 2
negativeNumberStyleRedAndParentheses = 3
negativeNumberStyleNone = 4
fractionAccuracyConflicting = 0
fractionAccuracyUpToOneDigit = -1
fractionAccuracyUpToTwoDigits = -2
fractionAccuracyUpToThreeDigits = -3
fractionAccuracyHalves = 2
fractionAccuracyQuarters = 4
fractionAccuracyEighths = 8
fractionAccuracySixteenths = 16
fractionAccuracyTenths = 10
fractionAccuracyHundredths = 100



_RECTARCHIVE = _descriptor.Descriptor(
  name='RectArchive',
  full_name='TSCH.RectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='TSCH.RectArchive.origin', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TSCH.RectArchive.size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=199,
)


_CHARTSNSNUMBERDOUBLEARCHIVE = _descriptor.Descriptor(
  name='ChartsNSNumberDoubleArchive',
  full_name='TSCH.ChartsNSNumberDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_archive', full_name='TSCH.ChartsNSNumberDoubleArchive.number_archive', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=254,
)


_CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE = _descriptor.Descriptor(
  name='ChartsNSArrayOfNSNumberDoubleArchive',
  full_name='TSCH.ChartsNSArrayOfNSNumberDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numbers', full_name='TSCH.ChartsNSArrayOfNSNumberDoubleArchive.numbers', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=311,
)


_DEPRECATEDCHART3DFILLARCHIVE = _descriptor.Descriptor(
  name='DEPRECATEDChart3DFillArchive',
  full_name='TSCH.DEPRECATEDChart3DFillArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='TSCH.DEPRECATEDChart3DFillArchive.fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lightingmodel', full_name='TSCH.DEPRECATEDChart3DFillArchive.lightingmodel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textureset_id', full_name='TSCH.DEPRECATEDChart3DFillArchive.textureset_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_type', full_name='TSCH.DEPRECATEDChart3DFillArchive.fill_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_index', full_name='TSCH.DEPRECATEDChart3DFillArchive.series_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=522,
)


_CHARTSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartStyleArchive',
  full_name='TSCH.ChartStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=524,
  serialized_end=588,
)


_CHARTNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartNonStyleArchive',
  full_name='TSCH.ChartNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=657,
)


_LEGENDSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendStyleArchive',
  full_name='TSCH.LegendStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.LegendStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=724,
)


_LEGENDNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendNonStyleArchive',
  full_name='TSCH.LegendNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.LegendNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=794,
)


_CHARTAXISSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisStyleArchive',
  full_name='TSCH.ChartAxisStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartAxisStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=864,
)


_CHARTAXISNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisNonStyleArchive',
  full_name='TSCH.ChartAxisNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartAxisNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=937,
)


_CHARTSERIESSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesStyleArchive',
  full_name='TSCH.ChartSeriesStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartSeriesStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1009,
)


_CHARTSERIESNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesNonStyleArchive',
  full_name='TSCH.ChartSeriesNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartSeriesNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1084,
)


_GRIDVALUE = _descriptor.Descriptor(
  name='GridValue',
  full_name='TSCH.GridValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numeric_value', full_name='TSCH.GridValue.numeric_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_value_1_0', full_name='TSCH.GridValue.date_value_1_0', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_value', full_name='TSCH.GridValue.duration_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_value', full_name='TSCH.GridValue.date_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1188,
)


_GRIDROW = _descriptor.Descriptor(
  name='GridRow',
  full_name='TSCH.GridRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCH.GridRow.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1231,
)


_REFERENCELINESTYLEARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineStyleArchive',
  full_name='TSCH.ReferenceLineStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ReferenceLineStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1305,
)


_REFERENCELINENONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineNonStyleArchive',
  full_name='TSCH.ReferenceLineNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ReferenceLineNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1382,
)

_RECTARCHIVE.fields_by_name['origin'].message_type = TSPMessages__pb2._POINT
_RECTARCHIVE.fields_by_name['size'].message_type = TSPMessages__pb2._SIZE
_DEPRECATEDCHART3DFILLARCHIVE.fields_by_name['fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_DEPRECATEDCHART3DFILLARCHIVE.fields_by_name['lightingmodel'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGMODELARCHIVE
_DEPRECATEDCHART3DFILLARCHIVE.fields_by_name['fill_type'].enum_type = TSCH3DArchives__pb2._FILLPROPERTYTYPE
_CHARTSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_LEGENDNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_GRIDROW.fields_by_name['value'].message_type = _GRIDVALUE
_REFERENCELINESTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_REFERENCELINENONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
DESCRIPTOR.message_types_by_name['RectArchive'] = _RECTARCHIVE
DESCRIPTOR.message_types_by_name['ChartsNSNumberDoubleArchive'] = _CHARTSNSNUMBERDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartsNSArrayOfNSNumberDoubleArchive'] = _CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['DEPRECATEDChart3DFillArchive'] = _DEPRECATEDCHART3DFILLARCHIVE
DESCRIPTOR.message_types_by_name['ChartStyleArchive'] = _CHARTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartNonStyleArchive'] = _CHARTNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendStyleArchive'] = _LEGENDSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendNonStyleArchive'] = _LEGENDNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisStyleArchive'] = _CHARTAXISSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisNonStyleArchive'] = _CHARTAXISNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesStyleArchive'] = _CHARTSERIESSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesNonStyleArchive'] = _CHARTSERIESNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['GridValue'] = _GRIDVALUE
DESCRIPTOR.message_types_by_name['GridRow'] = _GRIDROW
DESCRIPTOR.message_types_by_name['ReferenceLineStyleArchive'] = _REFERENCELINESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceLineNonStyleArchive'] = _REFERENCELINENONSTYLEARCHIVE
DESCRIPTOR.enum_types_by_name['ChartType'] = _CHARTTYPE
DESCRIPTOR.enum_types_by_name['AxisType'] = _AXISTYPE
DESCRIPTOR.enum_types_by_name['ScatterFormat'] = _SCATTERFORMAT
DESCRIPTOR.enum_types_by_name['SeriesDirection'] = _SERIESDIRECTION
DESCRIPTOR.enum_types_by_name['NumberValueType'] = _NUMBERVALUETYPE
DESCRIPTOR.enum_types_by_name['NegativeNumberStyle'] = _NEGATIVENUMBERSTYLE
DESCRIPTOR.enum_types_by_name['FractionAccuracy'] = _FRACTIONACCURACY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RectArchive = _reflection.GeneratedProtocolMessageType('RectArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECTARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.RectArchive)
  ))
_sym_db.RegisterMessage(RectArchive)

ChartsNSNumberDoubleArchive = _reflection.GeneratedProtocolMessageType('ChartsNSNumberDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSNSNUMBERDOUBLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartsNSNumberDoubleArchive)
  ))
_sym_db.RegisterMessage(ChartsNSNumberDoubleArchive)

ChartsNSArrayOfNSNumberDoubleArchive = _reflection.GeneratedProtocolMessageType('ChartsNSArrayOfNSNumberDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartsNSArrayOfNSNumberDoubleArchive)
  ))
_sym_db.RegisterMessage(ChartsNSArrayOfNSNumberDoubleArchive)

DEPRECATEDChart3DFillArchive = _reflection.GeneratedProtocolMessageType('DEPRECATEDChart3DFillArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEPRECATEDCHART3DFILLARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.DEPRECATEDChart3DFillArchive)
  ))
_sym_db.RegisterMessage(DEPRECATEDChart3DFillArchive)

ChartStyleArchive = _reflection.GeneratedProtocolMessageType('ChartStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartStyleArchive)
  ))
_sym_db.RegisterMessage(ChartStyleArchive)

ChartNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartNonStyleArchive)

LegendStyleArchive = _reflection.GeneratedProtocolMessageType('LegendStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.LegendStyleArchive)
  ))
_sym_db.RegisterMessage(LegendStyleArchive)

LegendNonStyleArchive = _reflection.GeneratedProtocolMessageType('LegendNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.LegendNonStyleArchive)
  ))
_sym_db.RegisterMessage(LegendNonStyleArchive)

ChartAxisStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisStyleArchive)

ChartAxisNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisNonStyleArchive)

ChartSeriesStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSeriesStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesStyleArchive)

ChartSeriesNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSeriesNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesNonStyleArchive)

GridValue = _reflection.GeneratedProtocolMessageType('GridValue', (_message.Message,), dict(
  DESCRIPTOR = _GRIDVALUE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.GridValue)
  ))
_sym_db.RegisterMessage(GridValue)

GridRow = _reflection.GeneratedProtocolMessageType('GridRow', (_message.Message,), dict(
  DESCRIPTOR = _GRIDROW,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.GridRow)
  ))
_sym_db.RegisterMessage(GridRow)

ReferenceLineStyleArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINESTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ReferenceLineStyleArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineStyleArchive)

ReferenceLineNonStyleArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINENONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ReferenceLineNonStyleArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineNonStyleArchive)


# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSACommandArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSAArchives_sos_pb2 as TSAArchives__sos__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSACommandArchives_sos.proto',
  package='TSA',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1cTSACommandArchives_sos.proto\x12\x03TSA\x1a\x15TSAArchives_sos.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\"\xd2\x01\n4InducedVerifyDrawableZOrdersWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x45\n\x1dserver_drawable_z_order_lists\x18\x02 \x03(\x0b\x32\x1e.TSA.DrawableZOrderListArchive\x12/\n\'server_drawable_z_order_lists_undefined\x18\x03 \x01(\x08\"\xb8\x01\n#PropagateMasterChangeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x36\n#uuids_of_previously_visited_objects\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\x35\n-uuids_of_previously_visited_objects_undefined\x18\x03 \x01(\x08\"\x97\x01\n\x1b\x43ommandReapplyMasterArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\x0eitems_to_visit\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12 \n\x18items_to_visit_undefined\x18\x03 \x01(\x08\x12\x0f\n\x07is_undo\x18\x04 \x02(\x08\"L\n&VerifyDocumentWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"\x9c\x01\n-VerifyDrawableZOrdersWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12#\n\x10\x64rawable_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x1a\x64rawable_id_list_undefined\x18\x03 \x01(\x08\"\x90\x01\n%VerifyObjectsWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\x0eobject_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12 \n\x18object_id_list_undefined\x18\x03 \x01(\x08\"\x82\x01\n.VerifyTransformHistoryWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x16\n\x0esequence_start\x18\x02 \x02(\x05\x12\x14\n\x0csequence_end\x18\x03 \x02(\x05')
  ,
  dependencies=[TSAArchives__sos__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,])




_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDrawableZOrdersWithServerCommandArchive',
  full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_drawable_z_order_lists', full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive.server_drawable_z_order_lists', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_drawable_z_order_lists_undefined', full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive.server_drawable_z_order_lists_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=309,
)


_PROPAGATEMASTERCHANGECOMMANDARCHIVE = _descriptor.Descriptor(
  name='PropagateMasterChangeCommandArchive',
  full_name='TSA.PropagateMasterChangeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.PropagateMasterChangeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuids_of_previously_visited_objects', full_name='TSA.PropagateMasterChangeCommandArchive.uuids_of_previously_visited_objects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuids_of_previously_visited_objects_undefined', full_name='TSA.PropagateMasterChangeCommandArchive.uuids_of_previously_visited_objects_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=496,
)


_COMMANDREAPPLYMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandReapplyMasterArchive',
  full_name='TSA.CommandReapplyMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.CommandReapplyMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items_to_visit', full_name='TSA.CommandReapplyMasterArchive.items_to_visit', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items_to_visit_undefined', full_name='TSA.CommandReapplyMasterArchive.items_to_visit_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_undo', full_name='TSA.CommandReapplyMasterArchive.is_undo', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=650,
)


_VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyDocumentWithServerCommandArchive',
  full_name='TSA.VerifyDocumentWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyDocumentWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=728,
)


_VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyDrawableZOrdersWithServerCommandArchive',
  full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_id_list', full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive.drawable_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_id_list_undefined', full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive.drawable_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=887,
)


_VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyObjectsWithServerCommandArchive',
  full_name='TSA.VerifyObjectsWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyObjectsWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_id_list', full_name='TSA.VerifyObjectsWithServerCommandArchive.object_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_id_list_undefined', full_name='TSA.VerifyObjectsWithServerCommandArchive.object_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1034,
)


_VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyTransformHistoryWithServerCommandArchive',
  full_name='TSA.VerifyTransformHistoryWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyTransformHistoryWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_start', full_name='TSA.VerifyTransformHistoryWithServerCommandArchive.sequence_start', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_end', full_name='TSA.VerifyTransformHistoryWithServerCommandArchive.sequence_end', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1167,
)

_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['server_drawable_z_order_lists'].message_type = TSAArchives__sos__pb2._DRAWABLEZORDERLISTARCHIVE
_PROPAGATEMASTERCHANGECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_PROPAGATEMASTERCHANGECOMMANDARCHIVE.fields_by_name['uuids_of_previously_visited_objects'].message_type = TSPMessages__pb2._UUID
_COMMANDREAPPLYMASTERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREAPPLYMASTERARCHIVE.fields_by_name['items_to_visit'].message_type = TSPMessages__pb2._UUID
_VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['drawable_id_list'].message_type = TSPMessages__pb2._UUID
_VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE.fields_by_name['object_id_list'].message_type = TSPMessages__pb2._UUID
_VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDrawableZOrdersWithServerCommandArchive'] = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['PropagateMasterChangeCommandArchive'] = _PROPAGATEMASTERCHANGECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandReapplyMasterArchive'] = _COMMANDREAPPLYMASTERARCHIVE
DESCRIPTOR.message_types_by_name['VerifyDocumentWithServerCommandArchive'] = _VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['VerifyDrawableZOrdersWithServerCommandArchive'] = _VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['VerifyObjectsWithServerCommandArchive'] = _VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['VerifyTransformHistoryWithServerCommandArchive'] = _VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InducedVerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyDrawableZOrdersWithServerCommandArchive)

PropagateMasterChangeCommandArchive = _reflection.GeneratedProtocolMessageType('PropagateMasterChangeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROPAGATEMASTERCHANGECOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.PropagateMasterChangeCommandArchive)
  ))
_sym_db.RegisterMessage(PropagateMasterChangeCommandArchive)

CommandReapplyMasterArchive = _reflection.GeneratedProtocolMessageType('CommandReapplyMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREAPPLYMASTERARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.CommandReapplyMasterArchive)
  ))
_sym_db.RegisterMessage(CommandReapplyMasterArchive)

VerifyDocumentWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyDocumentWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyDocumentWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyDocumentWithServerCommandArchive)

VerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyDrawableZOrdersWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyDrawableZOrdersWithServerCommandArchive)

VerifyObjectsWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyObjectsWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyObjectsWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyObjectsWithServerCommandArchive)

VerifyTransformHistoryWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyTransformHistoryWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyTransformHistoryWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyTransformHistoryWithServerCommandArchive)


# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import
import json

from .generated import KNArchives_pb2 as KNArchives
from .generated import KNArchives_sos_pb2 as KNArchives_sos
from .generated import KNCommandArchives_pb2 as KNCommandArchives
from .generated import KNCommandArchives_sos_pb2 as KNCommandArchives_sos
from .generated import TSAArchives_pb2 as TSAArchives
from .generated import TSAArchives_sos_pb2 as TSAArchives_sos
from .generated import TSACommandArchives_sos_pb2 as TSACommandArchives_sos
from .generated import TSCEArchives_pb2 as TSCEArchives
from .generated import TSCH3DArchives_pb2 as TSCH3DArchives
from .generated import TSCHArchives_Common_pb2 as TSCHArchives_Common
from .generated import TSCHArchives_GEN_pb2 as TSCHArchives_GEN
from .generated import TSCHArchives_pb2 as TSCHArchives
from .generated import TSCHArchives_sos_pb2 as TSCHArchives_sos
from .generated import TSCHCommandArchives_pb2 as TSCHCommandArchives
from .generated import TSCHPreUFFArchives_pb2 as TSCHPreUFFArchives
from .generated import TSDArchives_pb2 as TSDArchives
from .generated import TSDArchives_sos_pb2 as TSDArchives_sos
from .generated import TSDCommandArchives_pb2 as TSDCommandArchives
from .generated import TSKArchives_pb2 as TSKArchives
from .generated import TSPArchiveMessages_pb2 as TSPArchiveMessages
from .generated import TSPDatabaseMessages_pb2 as TSPDatabaseMessages
from .generated import TSPMessages_pb2 as TSPMessages
from .generated import TSSArchives_pb2 as TSSArchives
from .generated import TSSArchives_sos_pb2 as TSSArchives_sos
from .generated import TSTArchives_pb2 as TSTArchives
from .generated import TSTArchives_sos_pb2 as TSTArchives_sos
from .generated import TSTCommandArchives_pb2 as TSTCommandArchives
from .generated import TSTStylePropertyArchiving_pb2 as TSTStylePropertyArchiving
from .generated import TSWPArchives_pb2 as TSWPArchives
from .generated import TSWPArchives_sos_pb2 as TSWPArchives_sos
from .generated import TSWPCommandArchives_pb2 as TSWPCommandArchives

PROTO_FILES = [
    KNArchives,
    KNArchives_sos,
    KNCommandArchives,
    KNCommandArchives_sos,
    TSAArchives,
    TSAArchives_sos,
    TSACommandArchives_sos,
    TSCEArchives,
    TSCH3DArchives,
    TSCHArchives_Common,
    TSCHArchives_GEN,
    TSCHArchives,
    TSCHArchives_sos,
    TSCHCommandArchives,
    TSCHPreUFFArchives,
    TSDArchives,
    TSDArchives_sos,
    TSDCommandArchives,
    TSKArchives,
    TSPArchiveMessages,
    TSPDatabaseMessages,
    TSPMessages,
    TSSArchives,
    TSSArchives_sos,
    TSTArchives,
    TSTArchives_sos,
    TSTCommandArchives,
    TSTStylePropertyArchiving,
    TSWPArchives,
    TSWPArchives_sos,
    TSWPCommandArchives,
]

TSPRegistryMapping = json.loads(
    """
{
  "1": "KN.DocumentArchive",
  "2": "KN.ShowArchive",
  "3": "KN.UIStateArchive",
  "4": "KN.SlideNodeArchive",
  "5": "KN.SlideArchive",
  "6": "KN.SlideArchive",
  "7": "KN.PlaceholderArchive",
  "8": "KN.BuildArchive",
  "9": "KN.SlideStyleArchive",
  "10": "KN.ThemeArchive",
  "11": "KN.PasteboardNativeStorageArchive",
  "12": "KN.PlaceholderArchive",
  "14": "TSWP.TextualAttachmentArchive",
  "15": "KN.NoteArchive",
  "16": "KN.RecordingArchive",
  "17": "KN.RecordingEventTrackArchive",
  "18": "KN.RecordingMovieTrackArchive",
  "19": "KN.ClassicStylesheetRecordArchive",
  "20": "KN.ClassicThemeRecordArchive",
  "21": "KN.Soundtrack",
  "22": "KN.SlideNumberAttachmentArchive",
  "23": "KN.DesktopUILayoutArchive",
  "24": "KN.CanvasSelectionArchive",
  "25": "KN.SlideCollectionSelectionArchive",
  "100": "KN.CommandBuildSetValueArchive",
  "101": "KN.CommandShowInsertSlideArchive",
  "102": "KN.CommandShowMoveSlideArchive",
  "103": "KN.CommandShowRemoveSlideArchive",
  "104": "KN.CommandSlideInsertDrawablesArchive",
  "105": "KN.CommandSlideRemoveDrawableArchive",
  "106": "KN.CommandSlideNodeSetPropertyArchive",
  "107": "KN.CommandSlideInsertBuildArchive",
  "109": "KN.CommandSlideRemoveBuildArchive",
  "110": "KN.CommandSlideInsertBuildChunkArchive",
  "111": "KN.CommandSlideMoveBuildChunksArchive",
  "112": "KN.CommandSlideRemoveBuildChunkArchive",
  "114": "KN.CommandTransitionSetValueArchive",
  "118": "KN.CommandSlideMoveDrawableZOrderArchive",
  "119": "KN.CommandChangeMasterSlideArchive",
  "123": "KN.CommandShowSetSlideNumberVisibilityArchive",
  "124": "KN.CommandShowSetValueArchive",
  "128": "KN.CommandShowMarkOutOfSyncRecordingArchive",
  "129": "KN.CommandShowRemoveRecordingArchive",
  "130": "KN.CommandShowReplaceRecordingArchive",
  "131": "KN.CommandShowSetSoundtrack",
  "132": "KN.CommandSoundtrackSetValue",
  "134": "KN.CommandMoveMastersArchive",
  "135": "KN.CommandInsertMasterArchive",
  "136": "KN.CommandSlideSetStyleArchive",
  "137": "KN.CommandSlideSetPlaceholdersForTagsArchive",
  "138": "KN.CommandBuildChunkSetValueArchive",
  "140": "KN.CommandRemoveMasterArchive",
  "142": "KN.CommandMasterSetThumbnailTextArchive",
  "143": "KN.CommandShowChangeThemeArchive",
  "144": "KN.CommandSlidePrimitiveSetMasterArchive",
  "145": "KN.CommandMasterSetBodyStylesArchive",
  "146": "KN.CommandSlideReapplyMasterArchive",
  "148": "KN.ChartInfoGeometryCommandArchive",
  "150": "KN.CommandSlideUpdateMasterDrawables",
  "152": "KN.CommandSlideSetBackgroundFillArchive",
  "153": "KN.BuildChunkArchive",
  "156": "KN.CommandSlideNodeSetViewStatePropertyArchive",
  "157": "KN.CommandBuildUpdateChunkCountArchive",
  "158": "KN.CommandBuildUpdateChunkReferentsArchive",
  "159": "KN.BuildAttributeTupleArchive",
  "160": "KN.CommandSetThemeCustomEffectTimingCurveArchive",
  "161": "KN.CommandShowChangeSlideSizeArchive",
  "162": "KN.InsertBuildDescriptionArchive",
  "163": "KN.RemoveBuildDescriptionArchive",
  "164": "KN.DocumentSelectionTransformerArchive",
  "165": "KN.SlideCollectionSelectionTransformerArchive",
  "166": "KN.OutlineCanvasSelectionTransformerArchive",
  "167": "KN.NoteCanvasSelectionTransformerArchive",
  "168": "KN.CanvasSelectionTransformerArchive",
  "169": "KN.OutlineSelectionTransformerArchive",
  "170": "KN.UndoObjectArchive",
  "172": "KN.PrototypeForUndoMasterChangeArchive",
  "173": "KN.CommandShowMarkOutOfSyncRecordingIfNeededArchive",
  "174": "KN.InducedVerifyDocumentWithServerCommandArchive",
  "175": "KN.InducedVerifyDrawableZOrdersWithServerCommandArchive",
  "176": "KN.CommandPrimitiveInsertMasterArchive",
  "177": "KN.CommandPrimitiveRemoveMasterArchive",
  "178": "KN.CommandMasterSlideSetPlaceholderForTagArchive",
  "179": "KN.CommandSlidePropagateSetPlaceholderForTagArchive",
  "180": "KN.ActionGhostSelectionArchive",
  "181": "KN.ActionGhostSelectionTransformerArchive",
  "182": "KN.CommandSlideResetMasterBackgroundObjectsArchive",
  "200": "TSK.DocumentArchive",
  "201": "TSK.CommandHistory",
  "202": "TSK.CommandGroupArchive",
  "203": "TSK.CommandContainerArchive",
  "205": "TSK.TreeNode",
  "210": "TSK.ViewStateArchive",
  "211": "TSK.DocumentSupportArchive",
  "212": "TSK.AnnotationAuthorArchive",
  "213": "TSK.AnnotationAuthorStorageArchive",
  "215": "TSK.SetAnnotationAuthorColorCommandArchive",
  "218": "TSK.CollaborationCommandHistory",
  "219": "TSK.DocumentSelectionArchive",
  "220": "TSK.CommandSelectionBehaviorArchive",
  "221": "TSK.NullCommandArchive",
  "222": "TSK.CustomFormatListArchive",
  "223": "TSK.GroupCommitCommandArchive",
  "224": "TSK.InducedCommandCollectionArchive",
  "225": "TSK.InducedCommandCollectionCommitCommandArchive",
  "226": "TSK.CollaborationDocumentSessionState",
  "227": "TSK.CollaborationCommandHistoryCoalescingGroup",
  "228": "TSK.CollaborationCommandHistoryCoalescingGroupNode",
  "229": "TSK.CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver",
  "230": "TSK.DocumentSupportCollaborationState",
  "231": "TSK.ChangeDocumentPackageTypeCommandArchive",
  "232": "TSK.UpgradeDocPostProcessingCommandArchive",
  "233": "TSK.FinalCommandPairArchive",
  "234": "TSK.OutgoingCommandQueueItem",
  "235": "TSK.TransformerEntry",
  "238": "TSK.CreateLocalStorageSnapshotCommandArchive",
  "240": "TSK.SelectionPathTransformerArchive",
  "241": "TSK.NativeContentDescription",
  "242": "TSD.PencilAnnotationStorageArchive",
  "245": "TSK.OperationStorage",
  "246": "TSK.OperationStorageEntryArray",
  "247": "TSK.OperationStorageEntryArraySegment",
  "248": "TSK.BlockDiffsAtCurrentRevisionCommand",
  "249": "TSK.OutgoingCommandQueue",
  "250": "TSK.OutgoingCommandQueueSegment",
  "251": "TSK.PropagatedCommandCollectionArchive",
  "400": "TSS.StyleArchive",
  "401": "TSS.StylesheetArchive",
  "402": "TSS.ThemeArchive",
  "412": "TSS.StyleUpdatePropertyMapCommandArchive",
  "413": "TSS.ThemeReplacePresetCommandArchive",
  "414": "TSS.ThemeAddStylePresetCommandArchive",
  "415": "TSS.ThemeRemoveStylePresetCommandArchive",
  "416": "TSS.ThemeReplaceColorPresetCommandArchive",
  "417": "TSS.ThemeMovePresetCommandArchive",
  "419": "TSS.ThemeReplaceStylePresetAndDisconnectStylesCommandArchive",
  "600": "TSA.DocumentArchive",
  "601": "TSA.FunctionBrowserStateArchive",
  "602": "TSA.PropagatePresetCommandArchive",
  "603": "TSA.ShortcutControllerArchive",
  "604": "TSA.ShortcutCommandArchive",
  "605": "TSA.AddCustomFormatCommandArchive",
  "606": "TSA.UpdateCustomFormatCommandArchive",
  "607": "TSA.ReplaceCustomFormatCommandArchive",
  "611": "TSA.VerifyObjectsWithServerCommandArchive",
  "612": "TSA.InducedVerifyObjectsWithServerCommandArchive",
  "613": "TSA.VerifyDocumentWithServerCommandArchive",
  "614": "TSA.VerifyDrawableZOrdersWithServerCommandArchive",
  "615": "TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive",
  "616": "TSA.NeedsMediaCompatibilityUpgradeCommandArchive",
  "617": "TSA.ChangeDocumentLocaleCommandArchive",
  "618": "TSA.StyleUpdatePropertyMapCommandArchive",
  "619": "TSA.RemoteDataChangeCommandArchive",
  "623": "TSA.GalleryItem",
  "624": "TSA.GallerySelectionTransformer",
  "625": "TSA.GalleryItemSelection",
  "626": "TSA.GalleryItemSelectionTransformer",
  "627": "TSA.GalleryInfoSetValueCommandArchive",
  "628": "TSA.GalleryItemSetGeometryCommand",
  "629": "TSA.GalleryItemSetValueCommand",
  "630": "TSA.InducedVerifyTransformHistoryWithServerCommandArchive",
  "631": "TSA.CommandReapplyMasterArchive",
  "632": "TSA.PropagateMasterChangeCommandArchive",
  "633": "TSA.CaptionInfoArchive",
  "634": "TSA.CaptionPlacementArchive",
  "635": "TSA.TitlePlacementCommandArchive",
  "2001": "TSWP.StorageArchive",
  "2002": "TSWP.SelectionArchive",
  "2003": "TSWP.DrawableAttachmentArchive",
  "2004": "TSWP.TextualAttachmentArchive",
  "2005": "TSWP.StorageArchive",
  "2006": "TSWP.UIGraphicalAttachment",
  "2007": "TSWP.TextualAttachmentArchive",
  "2008": "TSWP.FootnoteReferenceAttachmentArchive",
  "2009": "TSWP.TextualAttachmentArchive",
  "2010": "TSWP.TSWPTOCPageNumberAttachmentArchive",
  "2011": "TSWP.ShapeInfoArchive",
  "2013": "TSWP.HighlightArchive",
  "2014": "TSWP.CommentInfoArchive",
  "2015": "TSWP.EquationInfoArchive",
  "2016": "TSWP.PencilAnnotationArchive",
  "2021": "TSWP.CharacterStyleArchive",
  "2022": "TSWP.ParagraphStyleArchive",
  "2023": "TSWP.ListStyleArchive",
  "2024": "TSWP.ColumnStyleArchive",
  "2025": "TSWP.ShapeStyleArchive",
  "2026": "TSWP.TOCEntryStyleArchive",
  "2031": "TSWP.PlaceholderSmartFieldArchive",
  "2032": "TSWP.HyperlinkFieldArchive",
  "2033": "TSWP.FilenameSmartFieldArchive",
  "2034": "TSWP.DateTimeSmartFieldArchive",
  "2035": "TSWP.BookmarkFieldArchive",
  "2036": "TSWP.MergeSmartFieldArchive",
  "2037": "TSWP.CitationRecordArchive",
  "2038": "TSWP.CitationSmartFieldArchive",
  "2039": "TSWP.UnsupportedHyperlinkFieldArchive",
  "2040": "TSWP.BibliographySmartFieldArchive",
  "2041": "TSWP.TOCSmartFieldArchive",
  "2042": "TSWP.RubyFieldArchive",
  "2043": "TSWP.NumberAttachmentArchive",
  "2050": "TSWP.TextStylePresetArchive",
  "2051": "TSWP.TOCSettingsArchive",
  "2052": "TSWP.TOCEntryInstanceArchive",
  "2053": "TSWP.StyleDiffArchive",
  "2060": "TSWP.ChangeArchive",
  "2061": "TSK.DeprecatedChangeAuthorArchive",
  "2062": "TSWP.ChangeSessionArchive",
  "2101": "TSWP.TextCommandArchive",
  "2107": "TSWP.ApplyPlaceholderTextCommandArchive",
  "2116": "TSWP.ApplyRubyTextCommandArchive",
  "2118": "TSWP.ModifyRubyTextCommandArchive",
  "2119": "TSWP.UpdateDateTimeFieldCommandArchive",
  "2120": "TSWP.ModifyTOCSettingsBaseCommandArchive",
  "2121": "TSWP.ModifyTOCSettingsForTOCInfoCommandArchive",
  "2122": "TSWP.ModifyTOCSettingsPresetForThemeCommandArchive",
  "2123": "TSWP.SetObjectPropertiesCommandArchive",
  "2124": "TSWP.UpdateFlowInfoCommandArchive",
  "2125": "TSWP.AddFlowInfoCommandArchive",
  "2126": "TSWP.RemoveFlowInfoCommandArchive",
  "2127": "TSWP.ContainedObjectsCommandArchive",
  "2128": "TSWP.EquationInfoGeometryCommandArchive",
  "2206": "TSWP.AnchorAttachmentCommandArchive",
  "2217": "TSWP.TextCommentReplyCommandArchive",
  "2231": "TSWP.ShapeApplyPresetCommandArchive",
  "2240": "TSWP.TOCInfoArchive",
  "2241": "TSWP.TOCAttachmentArchive",
  "2242": "TSWP.TOCLayoutHintArchive",
  "2400": "TSWP.StyleBaseCommandArchive",
  "2401": "TSWP.StyleCreateCommandArchive",
  "2402": "TSWP.StyleRenameCommandArchive",
  "2404": "TSWP.StyleDeleteCommandArchive",
  "2405": "TSWP.StyleReorderCommandArchive",
  "2406": "TSWP.StyleUpdatePropertyMapCommandArchive",
  "2407": "TSWP.StorageActionCommandArchive",
  "2408": "TSWP.ShapeStyleSetValueCommandArchive",
  "2409": "TSWP.HyperlinkSelectionArchive",
  "2410": "TSWP.FlowInfoArchive",
  "2411": "TSWP.FlowInfoContainerArchive",
  "2412": "TSWP.PencilAnnotationSelectionTransformerArchive",
  "3002": "TSD.DrawableArchive",
  "3003": "TSD.ContainerArchive",
  "3004": "TSD.ShapeArchive",
  "3005": "TSD.ImageArchive",
  "3006": "TSD.MaskArchive",
  "3007": "TSD.MovieArchive",
  "3008": "TSD.GroupArchive",
  "3009": "TSD.ConnectionLineArchive",
  "3015": "TSD.ShapeStyleArchive",
  "3016": "TSD.MediaStyleArchive",
  "3021": "TSD.InfoGeometryCommandArchive",
  "3022": "TSD.DrawablePathSourceCommandArchive",
  "3023": "TSD.ShapePathSourceFlipCommandArchive",
  "3024": "TSD.ImageMaskCommandArchive",
  "3025": "TSD.ImageMediaCommandArchive",
  "3026": "TSD.ImageReplaceCommandArchive",
  "3027": "TSD.MediaOriginalSizeCommandArchive",
  "3028": "TSD.ShapeStyleSetValueCommandArchive",
  "3030": "TSD.MediaStyleSetValueCommandArchive",
  "3031": "TSD.ShapeApplyPresetCommandArchive",
  "3032": "TSD.MediaApplyPresetCommandArchive",
  "3034": "TSD.MovieSetValueCommandArchive",
  "3036": "TSD.ExteriorTextWrapCommandArchive",
  "3037": "TSD.MediaFlagsCommandArchive",
  "3040": "TSD.DrawableHyperlinkCommandArchive",
  "3041": "TSD.ConnectionLineConnectCommandArchive",
  "3042": "TSD.InstantAlphaCommandArchive",
  "3043": "TSD.DrawableLockCommandArchive",
  "3044": "TSD.ImageNaturalSizeCommandArchive",
  "3045": "TSD.CanvasSelectionArchive",
  "3047": "TSD.GuideStorageArchive",
  "3048": "TSD.StyledInfoSetStyleCommandArchive",
  "3049": "TSD.DrawableInfoCommentCommandArchive",
  "3050": "TSD.GuideCommandArchive",
  "3051": "TSD.DrawableAspectRatioLockedCommandArchive",
  "3052": "TSD.ContainerRemoveChildrenCommandArchive",
  "3053": "TSD.ContainerInsertChildrenCommandArchive",
  "3054": "TSD.ContainerReorderChildrenCommandArchive",
  "3055": "TSD.ImageAdjustmentsCommandArchive",
  "3056": "TSD.CommentStorageArchive",
  "3057": "TSD.ThemeReplaceFillPresetCommandArchive",
  "3058": "TSD.DrawableAccessibilityDescriptionCommandArchive",
  "3059": "TSD.PasteStyleCommandArchive",
  "3061": "TSD.DrawableSelectionArchive",
  "3062": "TSD.GroupSelectionArchive",
  "3063": "TSD.PathSelectionArchive",
  "3064": "TSD.CommentInvalidatingCommandSelectionBehaviorArchive",
  "3065": "TSD.ImageInfoAbstractGeometryCommandArchive",
  "3066": "TSD.ImageInfoGeometryCommandArchive",
  "3067": "TSD.ImageInfoMaskGeometryCommandArchive",
  "3068": "TSD.UndoObjectArchive",
  "3070": "TSD.ReplaceAnnotationAuthorCommandArchive",
  "3071": "TSD.DrawableSelectionTransformerArchive",
  "3072": "TSD.GroupSelectionTransformerArchive",
  "3073": "TSD.ShapeSelectionTransformerArchive",
  "3074": "TSD.PathSelectionTransformerArchive",
  "3080": "TSD.MediaInfoGeometryCommandArchive",
  "3082": "TSD.GroupUngroupInformativeCommandArchive",
  "3083": "TSD.DrawableContentDescription",
  "3084": "TSD.ContainerRemoveDrawablesCommandArchive",
  "3085": "TSD.ContainerInsertDrawablesCommandArchive",
  "3086": "TSD.PencilAnnotationArchive",
  "3087": "TSD.FreehandDrawingOpacityCommandArchive",
  "3088": "TSD.DrawablePencilAnnotationCommandArchive",
  "3089": "TSD.PencilAnnotationSelectionArchive",
  "3090": "TSD.FreehandDrawingContentDescription",
  "3091": "TSD.FreehandDrawingToolkitUIState",
  "3092": "TSD.PencilAnnotationSelectionTransformerArchive",
  "3094": "TSD.FreehandDrawingAnimationCommandArchive",
  "3095": "TSD.InsertCaptionOrTitleCommandArchive",
  "3096": "TSD.RemoveCaptionOrTitleCommandArchive",
  "3097": "TSD.StandinCaptionArchive",
  "3098": "TSD.SetCaptionOrTitleVisibilityCommandArchive",
  "4000": "TSCE.CalculationEngineArchive",
  "4001": "TSCE.FormulaRewriteCommandArchive",
  "4002": "TSCE.TrackedReferencesRewriteCommandArchive",
  "4003": "TSCE.NamedReferenceManagerArchive",
  "4004": "TSCE.ReferenceTrackerArchive",
  "4005": "TSCE.TrackedReferenceArchive",
  "4006": "TSCE.ExtendTableIDHistoryCommandArchive",
  "4007": "TSCE.RemoteDataStoreArchive",
  "4008": "TSCE.FormulaOwnerDependenciesArchive",
  "4009": "TSCE.CellRecordTileArchive",
  "4010": "TSCE.RangePrecedentsTileArchive",
  "4011": "TSCE.ReferencesToDirtyArchive",
  "5000": "TSCH.PreUFF.ChartInfoArchive",
  "5002": "TSCH.PreUFF.ChartGridArchive",
  "5004": "TSCH.ChartMediatorArchive",
  "5010": "TSCH.PreUFF.ChartStyleArchive",
  "5011": "TSCH.PreUFF.ChartSeriesStyleArchive",
  "5012": "TSCH.PreUFF.ChartAxisStyleArchive",
  "5013": "TSCH.PreUFF.LegendStyleArchive",
  "5014": "TSCH.PreUFF.ChartNonStyleArchive",
  "5015": "TSCH.PreUFF.ChartSeriesNonStyleArchive",
  "5016": "TSCH.PreUFF.ChartAxisNonStyleArchive",
  "5017": "TSCH.PreUFF.LegendNonStyleArchive",
  "5020": "TSCH.ChartStylePreset",
  "5021": "TSCH.ChartDrawableArchive",
  "5022": "TSCH.ChartStyleArchive",
  "5023": "TSCH.ChartNonStyleArchive",
  "5024": "TSCH.LegendStyleArchive",
  "5025": "TSCH.LegendNonStyleArchive",
  "5026": "TSCH.ChartAxisStyleArchive",
  "5027": "TSCH.ChartAxisNonStyleArchive",
  "5028": "TSCH.ChartSeriesStyleArchive",
  "5029": "TSCH.ChartSeriesNonStyleArchive",
  "5030": "TSCH.ReferenceLineStyleArchive",
  "5031": "TSCH.ReferenceLineNonStyleArchive",
  "5103": "TSCH.CommandSetChartTypeArchive",
  "5104": "TSCH.CommandSetSeriesNameArchive",
  "5105": "TSCH.CommandSetCategoryNameArchive",
  "5107": "TSCH.CommandSetScatterFormatArchive",
  "5108": "TSCH.CommandSetLegendFrameArchive",
  "5109": "TSCH.CommandSetGridValueArchive",
  "5110": "TSCH.CommandSetGridDirectionArchive",
  "5115": "TSCH.CommandAddGridRowsArchive",
  "5116": "TSCH.CommandAddGridColumnsArchive",
  "5118": "TSCH.CommandMoveGridRowsArchive",
  "5119": "TSCH.CommandMoveGridColumnsArchive",
  "5122": "TSCH.CommandSetPieWedgeExplosion",
  "5123": "TSCH.CommandStyleSwapArchive",
  "5125": "TSCH.CommandChartApplyPreset",
  "5126": "TSCH.ChartCommandArchive",
  "5127": "TSCH.CommandReplaceGridValuesArchive",
  "5129": "TSCH.StylePasteboardDataArchive",
  "5130": "TSCH.CommandSetMultiDataSetIndexArchive",
  "5131": "TSCH.CommandReplaceThemePresetArchive",
  "5132": "TSCH.CommandInvalidateWPCaches",
  "5135": "TSCH.CommandMutatePropertiesArchive",
  "5136": "TSCH.CommandScaleAllTextArchive",
  "5137": "TSCH.CommandSetFontFamilyArchive",
  "5138": "TSCH.CommandApplyFillSetArchive",
  "5139": "TSCH.CommandReplaceCustomFormatArchive",
  "5140": "TSCH.CommandAddReferenceLineArchive",
  "5141": "TSCH.CommandDeleteReferenceLineArchive",
  "5142": "TSCH.CommandDeleteGridColumnsArchive",
  "5143": "TSCH.CommandDeleteGridRowsArchive",
  "5145": "TSCH.ChartSelectionArchive",
  "5146": "TSCH.ChartTextSelectionTransformerArchive",
  "5147": "TSCH.ChartSubselectionTransformerArchive",
  "5148": "TSCH.ChartDrawableSelectionTransformerArchive",
  "5149": "TSCH.ChartSubselectionTransformerHelperArchive",
  "5150": "TSCH.ChartRefLineSubselectionTransformerHelperArchive",
  "5151": "TSCH.CDESelectionTransformerArchive",
  "5152": "TSCH.ChartSubselectionIdentityTransformerHelperArchive",
  "5154": "TSCH.CommandPasteStyleArchive",
  "5155": "TSCH.CommandInducedReplaceChartGrid",
  "5156": "TSCH.CommandReplaceImageDataArchive",
  "6000": "TST.TableInfoArchive",
  "6001": "TST.TableModelArchive",
  "6002": "TST.Tile",
  "6003": "TST.TableStyleArchive",
  "6004": "TST.CellStyleArchive",
  "6005": "TST.TableDataList",
  "6006": "TST.HeaderStorageBucket",
  "6007": "TST.WPTableInfoArchive",
  "6008": "TST.TableStylePresetArchive",
  "6009": "TST.TableStrokePresetArchive",
  "6010": "TST.ConditionalStyleSetArchive",
  "6011": "TST.TableDataListSegment",
  "6030": "TST.SelectionArchive",
  "6031": "TST.CellMapArchive",
  "6032": "TST.DeathhawkRdar39989167CellSelectionArchive",
  "6033": "TST.ConcurrentCellMapArchive",
  "6034": "TST.ConcurrentCellListArchive",
  "6100": "TST.TableCommandArchive",
  "6101": "TST.CommandDeleteCellsArchive",
  "6102": "TST.CommandInsertColumnsOrRowsArchive",
  "6103": "TST.CommandRemoveColumnsOrRowsArchive",
  "6104": "TST.CommandResizeColumnOrRowArchive",
  "6107": "TST.CommandSetTableNameArchive",
  "6111": "TST.CommandChangeFreezeHeaderStateArchive",
  "6114": "TST.CommandSetTableNameEnabledArchive",
  "6117": "TST.CommandApplyTableStylePresetArchive",
  "6120": "TST.CommandSetRepeatingHeaderEnabledArchive",
  "6123": "TST.CommandSortArchive",
  "6125": "TST.CommandStyleTableArchive",
  "6126": "TST.CommandSetNumberOfDecimalPlacesArchive",
  "6127": "TST.CommandSetShowThousandsSeparatorArchive",
  "6128": "TST.CommandSetNegativeNumberStyleArchive",
  "6129": "TST.CommandSetFractionAccuracyArchive",
  "6131": "TST.CommandSetCurrencyCodeArchive",
  "6132": "TST.CommandSetUseAccountingStyleArchive",
  "6136": "TST.CommandSetTableFontNameArchive",
  "6137": "TST.CommandSetTableFontSizeArchive",
  "6142": "TST.CommandSetTableNameHeightArchive",
  "6144": "TST.MergeRegionMapArchive",
  "6145": "TST.CommandHideShowArchive",
  "6146": "TST.CommandSetBaseArchive",
  "6147": "TST.CommandSetBasePlacesArchive",
  "6148": "TST.CommandSetBaseUseMinusSignArchive",
  "6149": "TST.CommandSetTextStylePropertiesArchive",
  "6150": "TST.CommandCategoryChangeSummaryAggregateType",
  "6152": "TST.CommandCategoryResizeColumnOrRowArchive",
  "6153": "TST.CommandCategoryMoveRowsArchive",
  "6156": "TST.CommandSetPencilAnnotationsArchive",
  "6157": "TST.CommandCategoryWillChangeGroupValue",
  "6158": "TST.CommandApplyConcurrentCellMapArchive",
  "6179": "TST.FormulaEqualsTokenAttachmentArchive",
  "6181": "TST.TokenAttachmentArchive",
  "6182": "TST.ExpressionNodeArchive",
  "6183": "TST.BooleanNodeArchive",
  "6184": "TST.NumberNodeArchive",
  "6185": "TST.StringNodeArchive",
  "6186": "TST.ArrayNodeArchive",
  "6187": "TST.ListNodeArchive",
  "6188": "TST.OperatorNodeArchive",
  "6189": "TST.FunctionNodeArchive",
  "6190": "TST.DateNodeArchive",
  "6191": "TST.ReferenceNodeArchive",
  "6192": "TST.DurationNodeArchive",
  "6193": "TST.ArgumentPlaceholderNodeArchive",
  "6194": "TST.PostfixOperatorNodeArchive",
  "6195": "TST.PrefixOperatorNodeArchive",
  "6196": "TST.FunctionEndNodeArchive",
  "6197": "TST.EmptyExpressionNodeArchive",
  "6198": "TST.LayoutHintArchive",
  "6199": "TST.CompletionTokenAttachmentArchive",
  "6201": "TST.TableDataList",
  "6204": "TST.HiddenStateFormulaOwnerArchive",
  "6205": "TST.CommandSetAutomaticDurationUnitsArchive",
  "6206": "TST.PopUpMenuModel",
  "6218": "TST.RichTextPayloadArchive",
  "6220": "TST.FilterSetArchive",
  "6221": "TST.CommandSetFiltersEnabledArchive",
  "6224": "TST.CommandRewriteFilterFormulasForTableResizeArchive",
  "6226": "TST.CommandTextPreflightInsertCellArchive",
  "6228": "TST.CommandDeleteCellContentsArchive",
  "6229": "TST.CommandPostflightSetCellArchive",
  "6235": "TST.IdentifierNodeArchive",
  "6238": "TST.CommandSetDateTimeFormatArchive",
  "6239": "TST.TableCommandSelectionBehaviorArchive",
  "6244": "TST.CommandApplyCellCommentArchive",
  "6246": "TST.CommandSetFormulaTokenizationArchive",
  "6247": "TST.TableStyleNetworkArchive",
  "6250": "TST.CommandSetFilterSetTypeArchive",
  "6255": "TST.CommandSetTextStyleArchive",
  "6256": "TST.CommandJustForNotifyingArchive",
  "6258": "TST.CommandSetSortOrderArchive",
  "6262": "TST.CommandAddTableStylePresetArchive",
  "6264": "TST.CellDiffMapArchive",
  "6265": "TST.CommandApplyCellContentsArchive",
  "6266": "TST.CommandRemoveTableStylePresetArchive",
  "6267": "TST.ColumnRowUIDMapArchive",
  "6268": "TST.CommandMoveColumnsOrRowsArchive",
  "6269": "TST.CommandReplaceCustomFormatArchive",
  "6270": "TST.CommandReplaceTableStylePresetArchive",
  "6271": "TST.FormulaSelectionArchive",
  "6273": "TST.CellListArchive",
  "6275": "TST.CommandApplyCellDiffMapArchive",
  "6276": "TST.CommandSetFilterSetArchive",
  "6277": "TST.CommandMutateCellFormatArchive",
  "6278": "TST.CommandSetStorageLanguageArchive",
  "6280": "TST.CommandMergeArchive",
  "6281": "TST.CommandUnmergeArchive",
  "6282": "TST.CommandApplyCellMapArchive",
  "6283": "TST.ControlCellSelectionArchive",
  "6284": "TST.TableNameSelectionArchive",
  "6285": "TST.CommandRewriteFormulasForTransposeArchive",
  "6287": "TST.CommandTransposeTableArchive",
  "6289": "TST.CommandSetDurationStyleArchive",
  "6290": "TST.CommandSetDurationUnitSmallestLargestArchive",
  "6291": "TST.CommandRewriteTableFormulasForRewriteSpecArchive",
  "6292": "TST.CommandRewriteConditionalStylesForRewriteSpecArchive",
  "6293": "TST.CommandRewriteFilterFormulasForRewriteSpecArchive",
  "6294": "TST.CommandRewriteSortOrderForRewriteSpecArchive",
  "6295": "TST.StrokeSelectionArchive",
  "6297": "TST.LetNodeArchive",
  "6298": "TST.VariableNodeArchive",
  "6299": "TST.InNodeArchive",
  "6300": "TST.CommandInverseMergeArchive",
  "6301": "TST.CommandMoveCellsArchive",
  "6302": "TST.DefaultCellStylesContainerArchive",
  "6303": "TST.CommandRewriteMergeFormulasArchive",
  "6304": "TST.CommandChangeTableAreaForColumnOrRowArchive",
  "6305": "TST.StrokeSidecarArchive",
  "6306": "TST.StrokeLayerArchive",
  "6307": "TST.CommandChooseTableIdRemapperArchive",
  "6310": "TST.CommandSetWasCutArchive",
  "6311": "TST.AutofillSelectionArchive",
  "6312": "TST.StockCellSelectionArchive",
  "6313": "TST.CommandSetNowArchive",
  "6314": "TST.CommandSetStructuredTextImportRecordArchive",
  "6315": "TST.CommandRewriteCategoryFormulasArchive",
  "6316": "TST.SummaryModelArchive",
  "6317": "TST.SummaryCellVendorArchive",
  "6318": "TST.CategoryOrderArchive",
  "6320": "TST.CommandCategoryCollapseExpandGroupArchive",
  "6321": "TST.CommandCategorySetGroupingColumnsArchive",
  "6323": "TST.CommandRewriteHiddenStatesForGroupByChangeArchive",
  "6350": "TST.IdempotentSelectionTransformerArchive",
  "6351": "TST.TableSubSelectionTransformerBaseArchive",
  "6352": "TST.TableNameSelectionTransformerArchive",
  "6353": "TST.RegionSelectionTransformerArchive",
  "6354": "TST.RowColumnSelectionTransformerArchive",
  "6355": "TST.ControlCellSelectionTransformerArchive",
  "6357": "TST.ChangePropagationMapWrapper",
  "6358": "TST.WPSelectionTransformerArchive",
  "6359": "TST.StockCellSelectionTransformerArchive",
  "6360": "TST.CommandSetRangeControlMinMaxIncArchive",
  "6361": "TST.CommandCategorySetLabelRowVisibility",
  "6362": "TST.CommandRewritePencilAnnotationFormulasArchive",
  "6363": "TST.PencilAnnotationArchive",
  "6364": "TST.StrokeSelectionTransformerArchive",
  "6365": "TST.HeaderNameMgrTileArchive",
  "6366": "TST.HeaderNameMgrArchive",
  "6367": "TST.CellDiffArray",
  "6368": "TST.CellDiffArraySegment",
  "10011": "TSWP.SectionPlaceholderArchive",
  "10020": "TSWP.ShapeSelectionTransformerArchive",
  "10021": "TSWP.SelectionTransformerArchive",
  "10022": "TSWP.ShapeContentDescription",
  "10023": "TSWP.TateChuYokoFieldArchive",
  "10024": "TSWP.DropCapStyleArchive",
  "11000": "TSP.PasteboardObject",
  "11006": "TSP.PackageMetadata",
  "11007": "TSP.PasteboardMetadata",
  "11008": "TSP.ObjectContainer",
  "11009": "TSP.ViewStateMetadata",
  "11010": "TSP.ObjectCollection",
  "11011": "TSP.DocumentMetadata",
  "11012": "TSP.SupportMetadata",
  "11013": "TSP.ObjectSerializationMetadata",
  "11014": "TSP.DataMetadata",
  "11015": "TSP.DataMetadataMap",
  "11016": "TSP.LargeNumberArraySegment",
  "11017": "TSP.LargeStringArraySegment",
  "11018": "TSP.LargeLazyObjectArraySegment",
  "11019": "TSP.LargeNumberArray",
  "11020": "TSP.LargeStringArray",
  "11021": "TSP.LargeLazyObjectArray",
  "11022": "TSP.LargeStringToObjectDictionarySegment",
  "11023": "TSP.LargeStringToObjectDictionary",
  "11024": "TSP.LargeUUIDArraySegment",
  "11025": "TSP.LargeUUIDArray",
  "11026": "TSP.LargeObjectArraySegment",
  "11027": "TSP.LargeObjectArray"
}"""
)


def compute_maps():
    name_class_map = {}
    for file in PROTO_FILES:
        for message_name in file.DESCRIPTOR.message_types_by_name:
            message_type = getattr(file, message_name)
            name_class_map[message_type.DESCRIPTOR.full_name] = message_type

    id_name_map = {}
    for k, v in list(TSPRegistryMapping.items()):
        if v in name_class_map:
            id_name_map[int(k)] = name_class_map[v]

    return name_class_map, id_name_map


NAME_CLASS_MAP, ID_NAME_MAP = compute_maps()
